<?php
/**
 * Netnus Themes options
 *
 * @package Netnus Themes
 * @subpackage  Skitouring
 * @since  Skitouring 1.0.0
 */

/**
 * List of pages for page choices.
 * @return Array Array of page ids and name.
 */
function skitouring_page_choices() {
    $pages = get_pages();
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'skitouring' );
    foreach ( $pages as $page ) {
        $choices[ $page->ID ] = $page->post_title;
    }
    return  $choices;
}

/**
 * List of posts for post choices.
 * @return Array Array of post ids and name.
 */
function skitouring_post_choices() {
    $posts = get_posts( array( 'numberposts' => -1 ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'skitouring' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    wp_reset_postdata();
    return  $choices;
}

/**
 * List of category for category choices.
 * @return Array Array of post ids and name.
 */
function skitouring_category_choices() {
    $tax_args = array(
        'hierarchical' => 0,
        'taxonomy'     => 'category',
    );
    $taxonomies = get_categories( $tax_args );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'skitouring' );
    foreach ( $taxonomies as $tax ) {
        $choices[ $tax->term_id ] = $tax->name;
    }
    return  $choices;
}

if ( ! function_exists( 'skitouring_site_layout' ) ) :
    /**
     * Site Layout
     * @return array site layout options
     */
    function skitouring_site_layout() {
        $skitouring_site_layout = array(
            'wide'          => esc_url( get_template_directory_uri() . '/assets/images/full.png' ),
            'boxed-layout'  => esc_url( get_template_directory_uri() . '/assets/images/boxed.png' ),
        );

        $output = apply_filters( 'skitouring_site_layout', $skitouring_site_layout );
        return $output;
    }
endif;

if ( ! function_exists( 'skitouring_selected_sidebar' ) ) :
    /**
     * Sidebars options
     * @return array Sidbar positions
     */
    function skitouring_selected_sidebar() {
        $skitouring_selected_sidebar = array(
            'sidebar-1'             => esc_html__( 'Default Sidebar', 'skitouring' ),
            'optional-sidebar'      => esc_html__( 'Optional Sidebar 1', 'skitouring' ),
        );

        $output = apply_filters( 'skitouring_selected_sidebar', $skitouring_selected_sidebar );

        return $output;
    }
endif;


if ( ! function_exists( 'skitouring_global_sidebar_position' ) ) :
    /**
     * Global Sidebar position
     * @return array Global Sidebar positions
     */
    function skitouring_global_sidebar_position() {
        $skitouring_global_sidebar_position = array(
            'right-sidebar' => esc_url( get_template_directory_uri() . '/assets/images/right.png' ),
            'no-sidebar'    => esc_url( get_template_directory_uri() . '/assets/images/full.png' ),
        );

        $output = apply_filters( 'skitouring_global_sidebar_position', $skitouring_global_sidebar_position );

        return $output;
    }
endif;


if ( ! function_exists( 'skitouring_sidebar_position' ) ) :
    /**
     * Sidebar position
     * @return array Sidbar positions
     */
    function skitouring_sidebar_position() {
        $skitouring_sidebar_position = array(
            'right-sidebar'         => esc_url( get_template_directory_uri() . '/assets/images/right.png' ),
            'no-sidebar'            => esc_url( get_template_directory_uri() . '/assets/images/full.png' ),
        );

        $output = apply_filters( 'skitouring_sidebar_position', $skitouring_sidebar_position );

        return $output;
    }
endif;

if ( ! function_exists( 'skitouring_pagination_options' ) ) :
    /**
     * Pagination
     * @return array site pagination options
     */
    function skitouring_pagination_options() {
        $skitouring_pagination_options = array(
            'numeric'   => esc_html__( 'Numeric', 'skitouring' ),
            'default'   => esc_html__( 'Default(Older/Newer)', 'skitouring' ),
        );

        $output = apply_filters( 'skitouring_pagination_options', $skitouring_pagination_options );

        return $output;
    }
endif;

if ( ! function_exists( 'skitouring_switch_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function skitouring_switch_options() {
        $arr = array(
            'on'        => esc_html__( 'Enable', 'skitouring' ),
            'off'       => esc_html__( 'Disable', 'skitouring' )
        );
        return apply_filters( 'skitouring_switch_options', $arr );
    }
endif;

if ( ! function_exists( 'skitouring_hide_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function skitouring_hide_options() {
        $arr = array(
            'on'        => esc_html__( 'Yes', 'skitouring' ),
            'off'       => esc_html__( 'No', 'skitouring' )
        );
        return apply_filters( 'skitouring_hide_options', $arr );
    }
endif;

if ( ! function_exists( 'skitouring_sortable_sections' ) ) :
    /**
     * List of sections Control options
     * @return array List of Sections control options.
     */
    function skitouring_sortable_sections() {
        $options = skitouring_get_theme_options();
  
        $sections = array(

            'main'                   => esc_html__( 'Main Section', 'skitouring' ),
            'call_to_action'         => esc_html__( 'Call To Action', 'skitouring' ),
            'latest_posts'           => esc_html__( 'Latest Posts', 'skitouring' ),
            'weekly_top'             => esc_html__( 'Weekly Top', 'skitouring' ),
        );
         
        return apply_filters( 'skitouring_sortable_sections', $sections );
    }
endif;