<?php
/**
 * Netnus Themes basic theme structure hooks
 *
 * This file contains structural hooks.
 *
 * @package Netnus Themes
 * @subpackage  Skitouring
 * @since  Skitouring 1.0.0
 */

$options = skitouring_get_theme_options();  


if ( ! function_exists( 'skitouring_doctype' ) ) :
	/**
	 * Doctype Declaration.
	 *
	 * @since  Skitouring 1.0.0
	 */
	function skitouring_doctype() {
	?>
		<!DOCTYPE html>
			<html <?php language_attributes(); ?>>
	<?php
	}
endif;
add_action( 'skitouring_doctype', 'skitouring_doctype', 10 );


if ( ! function_exists( 'skitouring_head' ) ) :
	/**
	 * Header Codes
	 *
	 * @since  Skitouring 1.0.0
	 *
	 */
	function skitouring_head() {
		?>
		<meta charset="<?php bloginfo( 'charset' ); ?>">
		<meta name="viewport" content="width=device-width, initial-scale=1">
		<link rel="profile" href="http://gmpg.org/xfn/11">
		<?php if ( is_singular() && pings_open( get_queried_object() ) ) : ?>
			<link rel="pingback" href="<?php echo esc_url( get_bloginfo( 'pingback_url' ) ); ?>">
		<?php endif;
	}
endif;
add_action( 'skitouring_before_wp_head', 'skitouring_head', 10 );

if ( ! function_exists( 'skitouring_page_start' ) ) :
	/**
	 * Page starts html codes
	 *
	 * @since  Skitouring 1.0.0
	 *
	 */
	function skitouring_page_start() {
		?>
		<div id="page" class="site">
			<a class="skip-link screen-reader-text" href="#content"><?php esc_html_e( 'Skip to content', 'skitouring' ); ?></a>
		<?php
	}
endif;
add_action( 'skitouring_page_start_action', 'skitouring_page_start', 10 );

if ( ! function_exists( 'skitouring_page_end' ) ) :
	/**
	 * Page end html codes
	 *
	 * @since  Skitouring 1.0.0
	 *
	 */
	function skitouring_page_end() {
		?>
		</div><!-- #page -->
		<?php
	}
endif;
add_action( 'skitouring_page_end_action', 'skitouring_page_end', 10 );

if ( ! function_exists( 'skitouring_site_branding' ) ) :
	/**
	 * Site branding codes
	 *
	 * @since  Skitouring 1.0.0
	 *
	 */
	function skitouring_site_branding() {
		$options  = skitouring_get_theme_options();
		$header_txt_logo_extra = $options['header_txt_logo_extra'];	 ?>
		<div class="menu-overlay"></div>
		<header id="masthead" class="site-header" role="banner">
			<div class="site-branding-container">
				<div class="wrapper">
					<div class="site-branding-wrapper">
						<div class="site-branding">
							<?php if ( in_array( $header_txt_logo_extra, array( 'show-all', 'logo-title', 'logo-tagline' ) ) && has_custom_logo()  ) : ?>
								<div class="site-logo">
									<?php the_custom_logo(); ?>
								</div>
							<?php endif; 
	
							if ( in_array( $header_txt_logo_extra, array( 'show-all', 'title-only', 'logo-title', 'show-all', 'tagline-only', 'logo-tagline' ) ) ) : ?>
								<div id="site-identity">
									<?php
									if( in_array( $header_txt_logo_extra, array( 'show-all', 'title-only', 'logo-title' ) )  ) { ?>
											<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
										<?php
									} 
									if ( in_array( $header_txt_logo_extra, array( 'show-all', 'tagline-only', 'logo-tagline' ) ) ) {
										$description = get_bloginfo( 'description', 'display' );
										if ( $description || is_customize_preview() ) : ?>
											<p class="site-description"><?php echo esc_html( $description ); /* WPCS: xss ok. */ ?></p>
										<?php
										endif; 
									}?>
								</div>
							<?php endif; ?>
						</div>
					</div>
					<button class="menu-toggle" aria-controls="primary-menu" aria-expanded="false" title="Primary Menu">
					<?php
						echo skitouring_get_svg( array( 'icon' => 'menu', 'class' => 'icon-menu' ) );
						echo skitouring_get_svg( array( 'icon' => 'close', 'class' => 'icon-menu' ) );
					?>	
						<span class="menu-label"><?php esc_html_e('Menu', 'skitouring')?></span>		
					</button>
					<nav id="site-navigation" class="main-navigation" role="navigation" aria-label="Primary Menu">
						<?php  
							$search_html= null;
							$social_menu= null;
							if($options['search_icon_in_primary_menu_enable']){
								$search_html = sprintf(
												'<li class="search-menu"><a href="#" title="%1$s">%2$s%3$s</a><div id="search">%4$s</div>',
												esc_attr__('Search','skitouring'),
												skitouring_get_svg( array( 'icon' => 'search' ) ), 
												skitouring_get_svg( array( 'icon' => 'close' ) ), 
												get_search_form( $echo = false )
											);
								
							}else{
								$search_html = '';
							}

							if($options['social_menu_enable'] && has_nav_menu( 'social' )):
						
								$social_menu = sprintf('<li class="social-menu">%1$s</li>',
										wp_nav_menu(  array(
											'theme_location' => 'social',
											'container' => 'div',
											'container_class' => 'social-icons',
											'echo' => false,
											'depth' => 1,
											'link_before' => '<span class="screen-reader-text">',
											'link_after' => '</span>',
											'items_wrap' => '<ul id="%1$s" class="%2$s">'.$search_html.'%3$s</ul>',
											'fallback_cb' => false,
										) )
									);
								
							endif;

							wp_nav_menu( array(
								'theme_location' => 'primary',
								'container' => 'div',
								'menu_class' => 'menu nav-menu',
								'menu_id' => 'primary-menu',
								'echo' => true,
								'fallback_cb' => 'skitouring_menu_fallback_cb',
								'items_wrap' => '<ul id="%1$s" class="%2$s">%3$s'.$social_menu.'</ul>',
							) );


						?>
					</nav><!-- #site-navigation -->
				</div><!-- .wrapper-->
			</div><!-- .site-branding-container-->
		</header>
<?php 
	}
endif;
add_action( 'skitouring_header_action', 'skitouring_site_branding', 10 );

if ( ! function_exists( 'skitouring_content_start' ) ) :
	/**
	 * Site content codes
	 *
	 * @since  Skitouring 1.0.0
	 *
	 */
	function skitouring_content_start() {
		?>
		<div id="content" class="site-content">
		<?php
	}
endif;
add_action( 'skitouring_content_start_action', 'skitouring_content_start', 10 );

if ( ! function_exists( 'skitouring_header_image' ) ) :
    /**
     * Header Image codes
     *
     * @since  Skitouring 1.0.0
     *
     */
    function skitouring_header_image() {
        if ( skitouring_is_frontpage() )
            return;
        $header_image = get_header_image();
        if ( is_singular() ) :
            $header_image = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : $header_image;
        endif;
        ?>

        <div id="page-site-header" class="relative" style="background-image: url('<?php echo esc_url( $header_image ); ?>');">
            <div class="overlay"></div>
            <div class="wrapper">
                <header class="page-header">
                    <?php skitouring_custom_header_banner_title(); ?>
                </header>
                <?php skitouring_add_breadcrumb(); ?>
            </div>
        </div><!-- #page-site-header -->

        <?php
    }
endif;
add_action( 'skitouring_header_image_action', 'skitouring_header_image', 10 );

if ( ! function_exists( 'skitouring_add_breadcrumb' ) ) :
	/**
	 * Add breadcrumb.
	 *
	 * @since  Skitouring 1.0.0
	 */
	function skitouring_add_breadcrumb() {
		$options = skitouring_get_theme_options();

		// Bail if Breadcrumb disabled.
		$breadcrumb = $options['breadcrumb_enable'];
		if ( false === $breadcrumb ) {
			return;
		}
		
		// Bail if Home Page.
		if ( skitouring_is_frontpage() ) {
			return;
		}

		echo '<div id="breadcrumb-list" >';
				/**
				 * skitouring_simple_breadcrumb hook
				 *
				 * @hooked skitouring_simple_breadcrumb -  10
				 *
				 */
				do_action( 'skitouring_simple_breadcrumb' );
		echo '</div><!-- #breadcrumb-list -->';
	}
endif;

if ( ! function_exists( 'skitouring_content_end' ) ) :
	/**
	 * Site content codes
	 *
	 * @since  Skitouring 1.0.0
	 *
	 */
	function skitouring_content_end() {
		?>
        </div><!-- #content -->
		<?php
	}
endif;
add_action( 'skitouring_content_end_action', 'skitouring_content_end', 10 );

if ( ! function_exists( 'skitouring_footer_start' ) ) :
	/**
	 * Footer starts
	 *
	 * @since  Skitouring 1.0.0
	 *
	 */
	function skitouring_footer_start() {
		?>
		<footer id="colophon" class="site-footer" role="contentinfo">
			
		<?php
	}
endif;
add_action( 'skitouring_footer', 'skitouring_footer_start', 10 );

if ( ! function_exists( 'skitouring_footer_site_info' ) ) :
	/**
	 * Footer starts
	 *
	 * @since  Skitouring 1.0.0
	 *
	 */
	function skitouring_footer_site_info() {
		$options = skitouring_get_theme_options();
		$search = array( '[the-year]', '[site-link]' );
		$theme_data = wp_get_theme();
        $replace = array( date( 'Y' ), '<a href="'. esc_url( home_url( '/' ) ) .'">'. esc_attr( get_bloginfo( 'name', 'display' ) ) . '</a>' );

        $options['copyright_text'] = str_replace( $search, $replace, $options['copyright_text'] );

		$copyright_text = $options['copyright_text'];
		?>
		<div class="site-info">
                <div class="wrapper">
                    <span>
                    <?php 
	                	echo skitouring_santize_allow_tag( $copyright_text ); 
	                	if ( function_exists( 'the_privacy_policy_link' ) ) {
							the_privacy_policy_link( ' | ' );
						}
                	?>                	
					<?php echo esc_html__( ' | All Rights Reserved | ', 'skitouring' ) . esc_html( $theme_data->get( 'Name') ) . '&nbsp;' . esc_html__( 'by', 'skitouring' ). '&nbsp;<a target="_blank" href="'. esc_url( $theme_data->get( 'AuthorURI' ) ) .'">'. esc_html( ucwords( $theme_data->get( 'Author' ) ) ) .'</a>' ?>
                	</span>
                </div><!-- .wrapper -->    
            </div><!-- .site-info -->

		<?php
	}
endif;
add_action( 'skitouring_footer', 'skitouring_footer_site_info', 40 );

if ( ! function_exists( 'skitouring_footer_scroll_to_top' ) ) :
	/**
	 * Footer starts
	 *
	 * @since  Skitouring 1.0.0
	 *
	 */
	function skitouring_footer_scroll_to_top() {
		$options  = skitouring_get_theme_options();
		if ( true === $options['scroll_top_visible'] ) : ?>
			<div class="backtotop"><?php echo skitouring_get_svg( array( 'icon' => 'up' ) ); ?></div>
		<?php endif;
	}
endif;
add_action( 'skitouring_footer', 'skitouring_footer_scroll_to_top', 40 );
